from distutils.core import setup

setup(
    name='test_package_cookiebus',
    version='1.1.1',
    py_modules=['fact', 'sum'],
    author='cookiebus',
    author_email='ngncmh@gmail.com',
    url='',
    description='test package'
)

